@@ -11,6 +11,25 @@ plapply <- function(workList,worker,parallelCluster) {
 }
 
 
+# rbind a list of dataframes into one
+.rbindListOfFrames <- function(rowlist) {
+  # catch trivial cases
+  if(length(rowlist)<=1) {
+    if(length(rowlist)<=0) {
+      return(NULL)
+    }
+    return(rowlist[[1]])
+  }
+  # see if a library can supply a fast method
+  if(requireNamespace("dplyr", quietly = TRUE)) {
+    return(as.data.frame(dplyr::bind_rows(rowlist),
+                         stringsAsFactor=FALSE))
+  }
+  # fall back to base R
+  do.call(rbind,rowlist)
+}
+
+
 
 # take in a column and return a column that is safely one of the primative
 # types: numeric, character 
@@ -251,7 +270,8 @@ catScore <- function(x,yC,yTarget,weights=c()) {
   if(is.null(weights)) {
     weights <- 1.0+numeric(n)
   }
-  tf <- data.frame(x=x,y=(yC==yTarget))
+  tf <- data.frame(x=x,y=(yC==yTarget),
+                   stringsAsFactors=FALSE)
   origOpt <- options()
   options(warn=-1)
   tryCatch({      
